# How to contribute?

This package is part of the [ComPWA Organization](https://github.com/ComPWA).
For more information about how to contribute to the packages, go to
[pwa.rtfd.io/develop.html](https://pwa.readthedocs.io/develop.html)!
